/******************************************************************************/
/* Sistemas Integrados TECNISA                                                */
/*                                                                            */
/* Qualidade de Fornecimento                                                  */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 8590_QFOSTP_APURA_QUALIF_FORN                                        */
/*                                                                            */
/* Descrio:                                                                 */
/*  Faz a apurao da qualificao dos fornecedores                           */
/*                                                                            */
/*                                                                            */
/* Criao:                                                                   */
/* 31/01/2001 - Joo Fernando dos Reis Corra                                 */
/*                                                                            */
/*                                                                            */
/******************************************************************************/
/******************************************************************************/
/* PARAMETROS:                                                                */
/* P_CDFILIPROC - Filial de processamento                                     */
/* P_CDOPERADOR - Operador do sistema                                         */
/* P_DTVALIDADE - Nova data de validade                                       */
/* P_ALTERARVAL - Indica se a data de validade ser auterada ou no           */
/* P_DTINIOCOR  - Data inicial da ocorrncia                                  */
/* P_DTFINOCOR  - Data final da ocorrncia                                    */
/* P_CDFILIAL   - Lista de Filiais                                            */
/* P_CDFORNECED - Lista de Fornecedores                                       */
/* P_TODAS      - Todas as Filiais                                            */
/* P_TODOS      - Todos os Fornecedores                                       */
/******************************************************************************/
/* @C:\SISTEMAS\DBA\SQL\ORACLE\8590_QFOSTP_APURA_QUALIF_FORN.SQL              */
/* @H:\SISTEMAS\DBA\SQL\ORACLE\8590_QFOSTP_APURA_QUALIF_FORN..SQL             */
/******************************************************************************/
CREATE OR REPLACE PROCEDURE APURA_QUALIF_FORN
(
   P_CDFILIPROC   IN FILIAL.CDFILIAL%TYPE,
   P_CDOPERADOR   IN OPERADOR.CDOPERADOR%TYPE,
   P_DTINIOCOR    IN DATA.DTDATA%TYPE,
   P_DTFINOCOR    IN DATA.DTDATA%TYPE,
   P_CDFILIAL     IN VARCHAR2,
   P_CDFORNECED   IN VARCHAR2,
   P_TODAS        IN VARCHAR2,
   P_TODOS        IN VARCHAR2
)
IS
   V_NRMAXOCORR   NUMBER;
   V_DTINIOCOR    DATE;
   V_DTFINOCOR    DATE;
   V_MAXNRDIAS    VARCHAR2(3);
   V_NRLOGAPURQFO VARCHAR2(20);
   V_CDQUAANT     VARCHAR2(2);
BEGIN
   /*Diminui o intervalo da Apurao, por questo de performance, para intervalos
     informados grandes.*/
  SELECT
      TO_DATE(MIN(DTOCORRMOV)),
      TO_DATE(MAX(DTOCORRMOV)),
      MAX(NRDIASOCORR)
   INTO
      V_DTINIOCOR,
      V_DTFINOCOR,
      V_MAXNRDIAS
   FROM
       TOLECONF, OCORRENCIA, MOVOCORR
   WHERE
      (INSTR(P_CDFORNECED, MOVOCORR.CDFORNECED) <> 0 OR P_TODOS = 'T') AND
      (INSTR(P_CDFILIAL, MOVOCORR.CDFILIAL)     <> 0 OR P_TODAS = 'T') AND
      (MOVOCORR.CDGRPOCOR  = OCORRENCIA.CDGRPOCOR)  AND
      (MOVOCORR.CDOCORR    = OCORRENCIA.CDOCORR)    AND
      (TOLECONF.CDTIPRISCO = OCORRENCIA.CDTIPRISCO) AND
      TO_DATE(DTOCORRMOV) BETWEEN P_DTINIOCOR AND P_DTFINOCOR;

   IF (V_DTFINOCOR - V_DTINIOCOR) < V_MAXNRDIAS THEN
      V_DTINIOCOR := P_DTINIOCOR;
      V_DTFINOCOR := P_DTFINOCOR;
   END IF;

   FOR C_FORN IN/*Retorna todos os fornecedores que tiveram ocorrncia*/
      (SELECT
          MOVOCORR.CDFORNECED,
          TOLECONF.CDTIPRISCO,
          TOLECONF.NRMAXOCORR,
          TOLECONF.NRDIASOCORR,
          TOLECONF.CDQUALIF,
          FORNECEDOR.DTVALQUALIF
       FROM
          MOVOCORR,
          OCORRENCIA,
          TOLECONF,
          FORNECEDOR
       WHERE
          (FORNECEDOR.CDFORNECED = MOVOCORR.CDFORNECED) AND
          (INSTR(P_CDFORNECED, MOVOCORR.CDFORNECED) <> 0 OR P_TODOS = 'T') AND
          (INSTR(P_CDFILIAL, MOVOCORR.CDFILIAL)     <> 0 OR P_TODAS = 'T') AND
          (MOVOCORR.CDGRPOCOR  = OCORRENCIA.CDGRPOCOR)  AND
          (MOVOCORR.CDOCORR    = OCORRENCIA.CDOCORR)    AND
          (TOLECONF.CDTIPRISCO = OCORRENCIA.CDTIPRISCO) AND
          (TO_DATE(MOVOCORR.DTOCORRMOV) BETWEEN V_DTINIOCOR AND V_DTFINOCOR)
       GROUP BY
          MOVOCORR.CDFORNECED,
          TOLECONF.NRDIASOCORR,
          TOLECONF.CDTIPRISCO,
          TOLECONF.NRMAXOCORR,
          TOLECONF.CDQUALIF,
          FORNECEDOR.DTVALQUALIF)
   LOOP
      FOR C_DATA IN/*Separa o intervalo de datas em perodos, de acordo com*/
         (SELECT   /*o nmero de dias de ocorrncia.*/
             DTDATA AS DTPERINI,
             DTDATA + C_FORN.NRDIASOCORR - 1 AS DTPERFIN
          FROM
             DATA
          WHERE
             DTDATA BETWEEN V_DTINIOCOR AND V_DTFINOCOR - C_FORN.NRDIASOCORR + 1)
      LOOP
         SELECT
            COUNT(*) INTO V_NRMAXOCORR  /*Nmero de ocorrncias neste perodo.*/
         FROM
            MOVOCORR, OCORRENCIA
         WHERE
            MOVOCORR.CDGRPOCOR = OCORRENCIA.CDGRPOCOR AND
            MOVOCORR.CDOCORR = OCORRENCIA.CDOCORR     AND
            MOVOCORR.CDFORNECED = C_FORN.CDFORNECED   AND
            OCORRENCIA.CDTIPRISCO = C_FORN.CDTIPRISCO AND
            TO_DATE(DTOCORRMOV) BETWEEN C_DATA.DTPERINI AND C_DATA.DTPERFIN;

         IF V_NRMAXOCORR > C_FORN.NRMAXOCORR THEN
            SELECT
               CDQUALIF INTO V_CDQUAANT/* Retorna a qulificao do fornecedor */
            FROM                       /* antes da apurao.*/
               FORNECEDOR
            WHERE
               CDFORNECED = C_FORN.CDFORNECED;

            UPDATE               /*Se o nmero de ocorrncias for MAIOR que*/
               FORNECEDOR        /*o permitido ento updata a qualificao*/
            SET                  /*e a data.*/
               CDQUALIF    = C_FORN.CDQUALIF,
               DTVALQUALIF = NVL(C_FORN.DTVALQUALIF, TO_DATE(SYSDATE)) + C_FORN.NRDIASOCORR,
               IDFORNAUTO  = 'N'
            WHERE
               FORNECEDOR.CDFORNECED = C_FORN.CDFORNECED;

            NOVO_CODIGO('LOGAPURQFO'||P_CDFILIPROC, V_NRLOGAPURQFO);
            INSERT INTO LOGAPURQFO (CDFILIAL,
                                    NRLOGAPURQFO,
                                    DTHRAPURQFO,
                                    DTINIAPURQFO,
                                    DTFINAPURQFO,
                                    CDOPERADOR,
                                    CDFORNECED,
                                    CDQUAANT,
                                    CDQUADEP)
                        VALUES (P_CDFILIPROC,
                                SUBSTR(V_NRLOGAPURQFO, 11, 10),
                                SYSDATE,
                                P_DTINIOCOR,
                                P_DTFINOCOR,
                                P_CDOPERADOR,
                                C_FORN.CDFORNECED,
                                V_CDQUAANT,
                                C_FORN.CDQUALIF);

            INSERT INTO OCOAPURQFO (CDFILIAL,
                                    NRLOGAPURQFO,
                                    CDFILILANCMO,
                                    NROCORRMOV)
                        (SELECT
                            P_CDFILIPROC,
                            SUBSTR(V_NRLOGAPURQFO, 11, 10),
                            MOVOCORR.CDFILILANCMO,
                            MOVOCORR.NROCORRMOV
                         FROM
                            MOVOCORR, OCORRENCIA
                         WHERE
                            (INSTR(P_CDFILIAL, MOVOCORR.CDFILIAL) <> 0 OR P_TODAS = 'T') AND
                            (TO_DATE(MOVOCORR.DTOCORRMOV) BETWEEN V_DTINIOCOR AND V_DTFINOCOR) AND
                            (MOVOCORR.CDGRPOCOR = OCORRENCIA.CDGRPOCOR)  AND
                            (MOVOCORR.CDOCORR = OCORRENCIA.CDOCORR) AND
                            (OCORRENCIA.CDTIPRISCO = C_FORN.CDTIPRISCO) AND
                            (MOVOCORR.CDFORNECED = C_FORN.CDFORNECED));
            EXIT;
         END IF;
      END LOOP;
   END LOOP;
END;
/


-- VERSAO --
BEGIN ATUVEROBJ('APURA_QUALIF_FORN','4.05.120'); END;
/

