/*+
|                                               |
|          Procedure: ETL_COMPRASGER            |
|                                               |
| Rotina para insero de dados de BI -         |
| valores de Compras / Suprimentos,             |
| para visualizao no CVI.                     |
|                                               |
|            Tabelas Preenchidas:               |
|                                               |
|       1: ETLCOMPRASGER - Faturamento          |
|                                               |
|     Criao:                                  |
|     29/02/2008 - Raphael Ernani Rodrigues     |
|     Converso (SQL Server):                   |
|     04/03/2008 - Leonardo Bispo de Souza      |
|                                               |
+*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'ETL_COMPRASGER' AND
	        TYPE = 'P' 	          AND
	        U.UID = O.UID             AND
	        U.NAME = USER
          )
	DROP PROCEDURE ETL_COMPRASGER
GO

CREATE PROCEDURE ETL_COMPRASGER
                          @P_DTINI       DATETIME,
                          @P_DTFINA      DATETIME
AS

   DECLARE @V_COUNTER       NUMERIC;

   /*MS ATUAL*/
   DECLARE @V_DTFIM         DATETIME;
   DECLARE @V_DTINI         DATETIME;

   /*MS ANTERIOR*/
   DECLARE @V_INIMESANT     DATETIME;
   DECLARE @V_FIMMESANT     DATETIME;

   /*DIMENSES DE TEMPO*/
   DECLARE @V_MES           VARCHAR(02);
   DECLARE @V_ANO           VARCHAR(04);
   DECLARE @V_BIM           VARCHAR(06);
   DECLARE @V_TRI           VARCHAR(06);
   DECLARE @V_SEM           VARCHAR(06);

   /*FATOS*/
   /*AF's*/
   DECLARE @V_VRCMPMEATUAF   DOUBLE PRECISION;
   DECLARE @V_VRCMPMEANTAF   DOUBLE PRECISION;

   DECLARE @V_QTPRCMPATUAF   DOUBLE PRECISION;
   DECLARE @V_QTPRCMPANTAF   DOUBLE PRECISION;

   DECLARE @VRCMPAFBAIXATOT  DOUBLE PRECISION; --Vr. AF Baixa Total
   DECLARE @VRCMPAFBAIXAPAR  DOUBLE PRECISION; --Vr. AF Baixa Parcial
   DECLARE @VRCMPAFBAIXAMAN  DOUBLE PRECISION; --Vr. AF Baixa Manual
   DECLARE @VRCMPAFBAIXAENC  DOUBLE PRECISION; --Vr. AF Encerrada
   DECLARE @VRCMPAFBAIXACAN  DOUBLE PRECISION; --Vr. AF Cancelada
   DECLARE @VRCMPAFBAIXAABE  DOUBLE PRECISION; --Vr. AF em Aberto

   DECLARE @QTCMPAFPREVISTA  DOUBLE PRECISION; --Qtde Prevista
   DECLARE @QTCMPAFSOLIPROD  DOUBLE PRECISION; --Qtde Solicitada

   DECLARE @VRCMPAFENCA      DOUBLE PRECISION; --Vr. AF Encargos
   DECLARE @VRCMPIMPAF       DOUBLE PRECISION; --Vr. AF Impostos
   DECLARE @VRCMPAFDESC      DOUBLE PRECISION; --Vr. AF Descontos

   /*NF's*/
   DECLARE @V_VRCMPMEATUNF   DOUBLE PRECISION;
   DECLARE @V_VRCMPMEANTNF   DOUBLE PRECISION;

   DECLARE @V_QTPRCMPATUNF   DOUBLE PRECISION;
   DECLARE @V_QTPRCMPANTNF   DOUBLE PRECISION;

   DECLARE @VRCMPNFDESC      DOUBLE PRECISION; --Vr. NF Descontos
   DECLARE @VRCMPNFENCA      DOUBLE PRECISION; --Vr. NF Encargos
   DECLARE @VRCMPIMPNF       DOUBLE PRECISION; --Vr. NF Impostos

        -----VARIAVEIS PARA CURSORES-----
   DECLARE @C_ETL_CDFILIAL        VARCHAR(04);
   DECLARE @C_ETL_CDAREAGERE      VARCHAR(04);
   DECLARE @C_ETL_DTINICIALBI     VARCHAR(25);
   DECLARE @C_ETL_CDEMPRESA       VARCHAR(04);
   DECLARE @C_ETL_CDGOPERAC       VARCHAR(12);
   DECLARE @C_ETL_CDSUPERVISOR    VARCHAR(12);
   DECLARE @C_ETL_CDREGIAO        VARCHAR(03);

   DECLARE @C_CDCOMPRADOR         VARCHAR(12);

   DECLARE @C_CDMARCA             VARCHAR(05);

   DECLARE @C_FORN_CDFORNECED     VARCHAR(21);

   DECLARE @C_PROD_CDPRODUTO      VARCHAR(10);
   DECLARE @C_PROD_NMPRODUTO      VARCHAR(50);
   DECLARE @C_PROD_CDPRODESTO     VARCHAR(10);

   DECLARE @V_ZERO          NUMERIC;/*CONSTANTE*/

   DECLARE @V_PROD_VRFATOCONV    DOUBLE PRECISION;
   DECLARE @V_PROD_VRARREDCMP    DOUBLE PRECISION;
   DECLARE @V_PROD_CDPRODESTO    DOUBLE PRECISION;
   
   DECLARE @V_NMPRODESTO         VARCHAR(50);

BEGIN
   SET @V_ZERO    = 0;
   SET @V_COUNTER = 0;

   SET @V_VRCMPMEATUAF = 0;
   SET @V_VRCMPMEANTAF = 0;
   SET @V_VRCMPMEATUNF = 0;
   SET @V_VRCMPMEANTNF = 0;
   SET @V_QTPRCMPATUNF = 0;
   SET @V_QTPRCMPANTNF = 0;
   SET @V_QTPRCMPATUAF = 0;
   SET @V_QTPRCMPANTAF = 0;

   SET @V_MES   = (CONVERT (VARCHAR, MONTH (@P_DTINI)));
   SET @V_ANO   = (CONVERT (VARCHAR, YEAR  (@P_DTINI)));
   SET @V_DTINI =  CONVERT (DATETIME,('01/'+@V_MES+'/'+@V_ANO),103);


   BEGIN TRANSACTION
      DELETE FROM ETLCOMPRASGERAF
      WHERE  (CDANOBI > @V_ANO)
      OR     (CDANOBI = @V_ANO AND CDMESBI >= @V_MES);

      DELETE FROM ETLCOMPRASGERNF
      WHERE  (CDANOBI > @V_ANO)
      OR     (CDANOBI = @V_ANO AND CDMESBI >= @V_MES);

   COMMIT TRANSACTION;


   WHILE (@V_DTINI  <=  @P_DTFINA) BEGIN
      BEGIN TRANSACTION

         SET @V_DTFIM     = DATEADD(MM,1,@V_DTINI) - DAY(@V_DTINI);
         SET @V_INIMESANT = DATEADD(MM, -1, @V_DTINI);
         SET @V_FIMMESANT = DATEADD(MM,1,@V_INIMESANT) - DAY(@V_INIMESANT);

         SET @V_MES = CONVERT (VARCHAR, MONTH(@V_DTFIM));
         SET @V_ANO = CONVERT (VARCHAR, YEAR(@V_DTFIM));
         SET @V_BIM = CONVERT (VARCHAR, (ROUND(((@V_MES - 1) / 2),0) + 1))+' Bim';
         SET @V_TRI = CONVERT (VARCHAR, (ROUND(((@V_MES - 1) / 3),0) + 1))+' Tri';
         SET @V_SEM = CONVERT (VARCHAR, (ROUND(((@V_MES - 1) / 6),0) + 1))+' Sem';

         DECLARE C_ETL CURSOR FOR
            (
             SELECT
                   F.CDFILIAL, F.CDAREAGERE, F.DTINICIALBI,  F.CDEMPRESA,
                   F.CDREGIAO, F.CDGOPERAC,  F.CDSUPERVISOR
             FROM
                   FILIAL F
             WHERE
                   F.IDFUNCAOFILI IS NULL AND
                   F.DTINICIALBI  IS NOT NULL
             )
         OPEN C_ETL;

         FETCH NEXT FROM C_ETL INTO
                                   @C_ETL_CDFILIAL,    @C_ETL_CDAREAGERE, @C_ETL_DTINICIALBI,
                                   @C_ETL_CDEMPRESA,   @C_ETL_CDREGIAO,   @C_ETL_CDGOPERAC,
                                   @C_ETL_CDSUPERVISOR;

         WHILE (@@FETCH_STATUS = @V_ZERO) BEGIN
            IF (CONVERT (DATETIME, ('01' + '/' + CONVERT(VARCHAR, MONTH(@C_ETL_DTINICIALBI))+'/'+ CONVERT (VARCHAR, YEAR(@C_ETL_DTINICIALBI)))) <= @V_DTINI) BEGIN

               DECLARE C_FORN CURSOR FOR
                  (
                   SELECT CDFORNECED
                   FROM   FORNECEDOR
                   WHERE  CDFORNECED IN (/*FORNECEDORES QUE CONSTAM EM AFs */
                                         SELECT A.CDFORNECED
                                         FROM   ITEMAUTF I, AUTOFORNE A
                                         WHERE  A.NRAUTOFORN = I.NRAUTOFORN
                                           AND  A.CDFILDEST   = I.CDFILDEST
                                           AND  A.CDFILLANC   = I.CDFILLANC
                                           AND  (ISNULL(A.IDBAIXAAF,'0') <> '6')
                                           AND  DTPROGENTAF BETWEEN @V_INIMESANT AND @V_DTFIM
                                           AND  I.CDFILDEST = @C_ETL_CDFILIAL

                                         UNION ALL

                                         /*PRODUTOS QUE CONSTAM EM NFs */
                                         SELECT CDFORNECED
                                         FROM   NOTAFISCAL N, TIPOOPERAC T
                                         WHERE  N.IDENTRSAIDOP  = 'E'
                                           AND  T.IDGERANFCMP = 'S'
                                           AND  N.CDTIPOOPER = T.CDTIPOOPER
                                           AND  N.IDENTRSAIDOP = T.IDENTRSAIDOP
                                           AND  N.DTENTRSAID BETWEEN @V_INIMESANT AND @V_DTFIM
                                           AND  N.IDSTATUS    <> 'C'
                                           AND  N.CDFILIRECE = @C_ETL_CDFILIAL)
                  )
               OPEN C_FORN;

               FETCH NEXT FROM C_FORN INTO
               @C_FORN_CDFORNECED;

               WHILE (@@FETCH_STATUS = @V_ZERO) BEGIN
                  DECLARE C_PROD CURSOR FOR
                     (
                      SELECT P.CDPRODUTO, P.NMPRODUTO, P.CDPRODESTO, ISNULL(P.VRARREDCMP,0) VRARREDCMP, ISNULL(P.VRFATOCONV,1) VRFATOCONV
                      FROM PRODUTO P
                      WHERE P.CDPRODUTO IN (/*PRODUTOS QUE CONSTAM EM AFs */
                                            SELECT CDPRODUTO
                                            FROM   ITEMAUTF I, AUTOFORNE A
                                            WHERE  A.NRAUTOFORN = I.NRAUTOFORN
                                              AND  A.CDFILDEST   = I.CDFILDEST
                                              AND  A.CDFILLANC   = I.CDFILLANC
                                              AND  (ISNULL(A.IDBAIXAAF,'0') <> '6')
                                              AND  DTPROGENTAF BETWEEN @V_INIMESANT AND @V_DTFIM
                                              AND  I.CDFILDEST  = @C_ETL_CDFILIAL
                                              AND  A.CDFORNECED = @C_FORN_CDFORNECED

                                            UNION ALL

                                            /*PRODUTOS QUE CONSTAM EM NFs */
                                            SELECT I.CDPRODUTO
                                            FROM   ITEMPRODUTO I,
                                                   NOTAFISCAL N,
                                                   TIPOOPERAC T
                                            WHERE  I.CDFILIAL = N.CDFILIAL
                                              AND  I.NRLANCTONF = N.NRLANCTONF
                                              AND  N.IDENTRSAIDOP  = 'E'
                                              AND  T.IDGERANFCMP = 'S'
                                              AND  N.CDTIPOOPER = T.CDTIPOOPER
                                              AND  N.IDENTRSAIDOP = T.IDENTRSAIDOP
                                              AND  N.DTENTRSAID BETWEEN @V_INIMESANT AND @V_DTFIM
                                              AND  N.IDSTATUS    <> 'C'
                                              AND  N.CDFILIRECE = @C_ETL_CDFILIAL
                                              AND  N.CDFORNECED = @C_FORN_CDFORNECED
                                            )
                     )
                  OPEN C_PROD;

                  FETCH NEXT FROM C_PROD INTO
                  @C_PROD_CDPRODUTO, @C_PROD_NMPRODUTO, @C_PROD_CDPRODESTO ;
                                             
                  BEGIN                   
                     IF (@C_PROD_CDPRODUTO = @C_PROD_CDPRODESTO) BEGIN
                        SET @V_NMPRODESTO = @C_PROD_NMPRODUTO;
                     END ELSE BEGIN
                        SELECT 
                           @V_NMPRODESTO = NMPRODUTO
                        FROM 
                           PRODUTO
                        WHERE
                           CDPRODUTO = @C_PROD_CDPRODESTO;
                     END;
                  END;
                  IF @V_NMPRODESTO IS NULL
                     SET @V_NMPRODESTO = '';
                  END; 

                  WHILE (@@FETCH_STATUS = @V_ZERO) BEGIN
                    DECLARE C_COMPR CURSOR FOR
                      (SELECT
                         C.CDOPERADOR
                       FROM
                         COMPRADOR C
                       WHERE EXISTS (SELECT 1
                                     FROM ITEMAUTF I, AUTOFORNE A
                                     WHERE A.NRAUTOFORN= I.NRAUTOFORN
                                       AND A.CDFILDEST = I.CDFILDEST
                                       AND A.CDFILLANC = I.CDFILLANC
                                       AND A.CDOPERADOR= C.CDOPERADOR
                                       AND (ISNULL(A.IDBAIXAAF,'0') <> '6')
                                       AND I.DTPROGENTAF BETWEEN @V_INIMESANT AND @V_DTFIM
                                       AND I.CDFILDEST = @C_ETL_CDFILIAL
                                       AND A.CDFILDEST = @C_ETL_CDFILIAL
                                       AND A.CDFORNECED = @C_FORN_CDFORNECED)
                       )
                    OPEN C_COMPR;

                    FETCH NEXT FROM C_COMPR INTO @C_CDCOMPRADOR;

                    WHILE (@@FETCH_STATUS = @V_ZERO) BEGIN
                    DECLARE C_MARCA CURSOR FOR
                      (
                       SELECT
                         CDMARCA
                       FROM
                         MARCA
                       WHERE EXISTS (SELECT 1
                                     FROM ITEMAUTF I, AUTOFORNE A
                                     WHERE A.NRAUTOFORN  = I.NRAUTOFORN
                                       AND A.CDFILDEST   = I.CDFILDEST
                                       AND A.CDFILLANC   = I.CDFILLANC
                                       AND A.CDOPERADOR  = @C_CDCOMPRADOR
                                       AND I.CDMARCA     = MARCA.CDMARCA
                                       AND (ISNULL(A.IDBAIXAAF,'0') <> '6')
                                       AND I.DTPROGENTAF BETWEEN @V_INIMESANT AND @V_DTFIM
                                       AND I.CDFILDEST  = @C_ETL_CDFILIAL
                                       AND A.CDFILDEST  = @C_ETL_CDFILIAL
                                       AND A.CDFORNECED = @C_FORN_CDFORNECED)
                      )
                    OPEN C_MARCA;

                    FETCH NEXT FROM C_MARCA INTO @C_CDMARCA;

                    WHILE (@@FETCH_STATUS = @V_ZERO) BEGIN

                     /*AF - MS ANTERIOR*/
                     /*QUANTIDADE DE PRODUTO COMPRADA*/
                     /*Valor total da compra*/
                     BEGIN
                        SELECT @V_VRCMPMEANTAF = SUM(QTPROGENTAF* VRPREUNIAF),
                               @V_QTPRCMPANTAF = SUM(QTPROGENTAF)
                        FROM   ITEMAUTF I, AUTOFORNE A
                        WHERE  A.NRAUTOFORN = I.NRAUTOFORN
                          AND  A.CDFILDEST   = I.CDFILDEST
                          AND  A.CDFILLANC   = I.CDFILLANC
                          AND  (ISNULL(A.IDBAIXAAF,'0') <> '6')
                          AND  DTPROGENTAF BETWEEN @V_INIMESANT AND @V_FIMMESANT
                          AND  A.CDFILDEST = @C_ETL_CDFILIAL
                          AND  I.CDPRODUTO = @C_PROD_CDPRODUTO
                          AND  A.CDFORNECED = @C_FORN_CDFORNECED
                          AND  A.CDOPERADOR = @C_CDCOMPRADOR
                          AND  I.CDMARCA    = @C_CDMARCA;
                     END;
                     IF @V_VRCMPMEANTAF IS NULL BEGIN
                        SET @V_VRCMPMEANTAF = @V_ZERO;
                     END;
                     IF @V_QTPRCMPANTAF IS NULL BEGIN
                        SET @V_QTPRCMPANTAF = @V_ZERO;
                     END;

                     /*AF - MS ATUAL                */
                     /*QUANTIDADE DE PRODUTO COMPRADA*/
                     /*Valor total da compra         */
                     BEGIN
                        SELECT @V_VRCMPMEATUAF = SUM(QTPROGENTAF* VRPREUNIAF),
                               @V_QTPRCMPATUAF = SUM(QTPROGENTAF)
                        FROM   ITEMAUTF I, AUTOFORNE A
                        WHERE  A.NRAUTOFORN = I.NRAUTOFORN
                          AND  A.CDFILDEST   = I.CDFILDEST
                          AND  A.CDFILLANC   = I.CDFILLANC
                          AND  (ISNULL(A.IDBAIXAAF,'0') <> '6')
                          AND  DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM
                          AND  A.CDFILDEST = @C_ETL_CDFILIAL
                          AND  I.CDPRODUTO = @C_PROD_CDPRODUTO
                          AND  A.CDFORNECED = @C_FORN_CDFORNECED
                          AND  A.CDOPERADOR = @C_CDCOMPRADOR
                          AND  I.CDMARCA    = @C_CDMARCA;
                     END;
                     IF @V_VRCMPMEATUAF IS NULL BEGIN
                        SET @V_VRCMPMEATUAF = @V_ZERO;
                     END;
                     IF @V_QTPRCMPATUAF IS NULL BEGIN
                        SET @V_QTPRCMPATUAF = @V_ZERO;
                     END;

                   /*AF - Vr. AF Baixa Parcial*/

                   BEGIN
                     SELECT
                       @VRCMPAFBAIXAPAR = SUM(VRPREUNIAF*QTPROGENTAF)
                     FROM AUTOFORNE AF, ITEMAUTF IT
                     WHERE @C_CDCOMPRADOR = AF.CDOPERADOR
                       AND IT.CDPRODUTO  = @C_PROD_CDPRODUTO
                       AND IT.CDMARCA    = @C_CDMARCA
                       AND (AF.DTAUTOFORN BETWEEN @V_DTINI AND @V_DTFIM)
                       AND (IDBAIXAAF = 1)
                       AND @C_FORN_CDFORNECED = AF.CDFORNECED
                       AND AF.CDFILDEST = @C_ETL_CDFILIAL
                       AND AF.CDFILDEST = IT.CDFILDEST
                       AND AF.CDFILLANC = IT.CDFILLANC
                       AND AF.NRAUTOFORN = IT.NRAUTOFORN;
                   END;
                   IF @VRCMPAFBAIXAPAR IS NULL BEGIN
                      SET @VRCMPAFBAIXAPAR = @V_ZERO;
                   END;

                   /*AF - Vr. AF Baixa Total*/

                   BEGIN
                     SELECT
                       @VRCMPAFBAIXATOT = SUM(VRPREUNIAF*QTPROGENTAF)
                     FROM AUTOFORNE AF, ITEMAUTF IT
                     WHERE @C_CDCOMPRADOR = AF.CDOPERADOR
                       AND IT.CDPRODUTO  = @C_PROD_CDPRODUTO
                       AND IT.CDMARCA    = @C_CDMARCA
                       AND (IT.DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM)
                       AND (IDBAIXAAF = 2)
                       AND @C_FORN_CDFORNECED = AF.CDFORNECED
                       AND AF.CDFILDEST = @C_ETL_CDFILIAL
                       AND AF.CDFILDEST = IT.CDFILDEST
                       AND AF.CDFILLANC = IT.CDFILLANC
                       AND AF.NRAUTOFORN = IT.NRAUTOFORN;
                   END;
                   IF @VRCMPAFBAIXATOT IS NULL BEGIN
                      SET @VRCMPAFBAIXATOT = @V_ZERO;
                   END;

                   /*AF - Vr. AF Baixa Manual*/

                   BEGIN
                     SELECT
                       @VRCMPAFBAIXAMAN = SUM(VRPREUNIAF*QTPROGENTAF)
                     FROM AUTOFORNE AF, ITEMAUTF IT
                     WHERE @C_CDCOMPRADOR = AF.CDOPERADOR
                       AND IT.CDPRODUTO  = @C_PROD_CDPRODUTO
                       AND IT.CDMARCA    = @C_CDMARCA
                       AND (IT.DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM)
                       AND (IDBAIXAAF = 3)
                       AND @C_FORN_CDFORNECED = AF.CDFORNECED
                       AND AF.CDFILDEST = @C_ETL_CDFILIAL
                       AND AF.CDFILDEST = IT.CDFILDEST
                       AND AF.CDFILLANC = IT.CDFILLANC
                       AND AF.NRAUTOFORN = IT.NRAUTOFORN;
                   END;
                   IF @VRCMPAFBAIXAMAN IS NULL BEGIN
                      SET @VRCMPAFBAIXAMAN = @V_ZERO;
                   END;

                   /*AF - Vr. AF Encerrada*/

                   BEGIN
                     SELECT
                       @VRCMPAFBAIXAENC = SUM(VRPREUNIAF*QTPROGENTAF)
                     FROM AUTOFORNE AF, ITEMAUTF IT
                     WHERE @C_CDCOMPRADOR = AF.CDOPERADOR
                       AND IT.CDPRODUTO  = @C_PROD_CDPRODUTO
                       AND IT.CDMARCA    = @C_CDMARCA
                       AND (IT.DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM)
                       AND (IDBAIXAAF = 4)
                       AND @C_FORN_CDFORNECED = AF.CDFORNECED
                       AND AF.CDFILDEST = @C_ETL_CDFILIAL
                       AND AF.CDFILDEST = IT.CDFILDEST
                       AND AF.CDFILLANC = IT.CDFILLANC
                       AND AF.NRAUTOFORN = IT.NRAUTOFORN;
                   END;
                   IF @VRCMPAFBAIXAENC IS NULL BEGIN
                      SET @VRCMPAFBAIXAENC = @V_ZERO;
                   END;

                   /*AF - Vr. AF Cancelada*/

                   BEGIN
                     SELECT
                       @VRCMPAFBAIXACAN = SUM(VRPREUNIAF*QTPROGENTAF)
                     FROM AUTOFORNE AF, ITEMAUTF IT
                     WHERE @C_CDCOMPRADOR = AF.CDOPERADOR
                       AND IT.CDPRODUTO  = @C_PROD_CDPRODUTO
                       AND IT.CDMARCA    = @C_CDMARCA
                       AND (IT.DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM)
                       AND (IDBAIXAAF = 5)
                       AND @C_FORN_CDFORNECED = AF.CDFORNECED
                       AND AF.CDFILDEST = @C_ETL_CDFILIAL
                       AND AF.CDFILDEST = IT.CDFILDEST
                       AND AF.CDFILLANC = IT.CDFILLANC
                       AND AF.NRAUTOFORN = IT.NRAUTOFORN;
                   END;
                   IF @VRCMPAFBAIXACAN IS NULL BEGIN
                      SET @VRCMPAFBAIXACAN = @V_ZERO;
                   END;

                   /*AF - Vr. AF em Aberto*/

                   BEGIN
                     SELECT
                       @VRCMPAFBAIXAABE = SUM(VRPREUNIAF*QTPROGENTAF)
                     FROM AUTOFORNE AF, ITEMAUTF IT
                     WHERE @C_CDCOMPRADOR = AF.CDOPERADOR
                       AND IT.CDPRODUTO  = @C_PROD_CDPRODUTO
                       AND IT.CDMARCA    = @C_CDMARCA
                       AND (IT.DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM)
                       AND (IDBAIXAAF IS NULL)
                       AND @C_FORN_CDFORNECED = AF.CDFORNECED
                       AND AF.CDFILDEST = @C_ETL_CDFILIAL
                       AND AF.CDFILDEST = IT.CDFILDEST
                       AND AF.CDFILLANC = IT.CDFILLANC
                       AND AF.NRAUTOFORN = IT.NRAUTOFORN;
                   END;
                   IF @VRCMPAFBAIXAABE IS NULL BEGIN
                      SET @VRCMPAFBAIXAABE = @V_ZERO;
                   END;

                   /*AF - Quantidade Prevista*/
                   BEGIN
                      IF @V_PROD_VRARREDCMP > 0 BEGIN
                         SELECT
                            @QTCMPAFPREVISTA = CEILING((SUM(PC.QTPREVCONS)/@V_PROD_VRFATOCONV)/@V_PROD_VRARREDCMP)*@V_PROD_VRARREDCMP
                         FROM
                            PREVCONS PC
                         WHERE (PC.CDFILIAL  = @C_ETL_CDFILIAL)
                           AND (PC.CDPRODUTO = @V_PROD_CDPRODESTO)
                           AND (PC.DTPREVCONS BETWEEN @V_DTINI AND @V_DTFIM);
                      END
                      ELSE BEGIN
                         SELECT
                            @QTCMPAFPREVISTA = SUM(PC.QTPREVCONS)/@V_PROD_VRFATOCONV
                         FROM
                            PREVCONS PC
                         WHERE (PC.CDFILIAL  = @C_ETL_CDFILIAL)
                           AND (PC.CDPRODUTO = @V_PROD_CDPRODESTO)
                           AND (PC.DTPREVCONS BETWEEN @V_DTINI AND @V_DTFIM);
                      END;
                   END;
                   IF @QTCMPAFPREVISTA IS NULL BEGIN
                      SET @QTCMPAFPREVISTA = @V_ZERO;
                   END;

                   /*AF - Quantidade Solicitada*/

                   BEGIN
                      IF @V_PROD_VRARREDCMP > 0 BEGIN
                        SELECT
                           @QTCMPAFSOLIPROD =  CEILING((SUM(ITS.QTSOLIPROD)/@V_PROD_VRFATOCONV)/@V_PROD_VRARREDCMP)*@V_PROD_VRARREDCMP
                        FROM
                           ITEMSOLI ITS, PRODUTO PS
                        WHERE (ITS.CDFILSOLI = @C_ETL_CDFILIAL)
                          AND (ITS.CDPRODUTO = PS.CDPRODUTO)
                          AND (PS.CDPRODESTO = @V_PROD_CDPRODESTO)
                          AND (ITS.DTPROGENTR BETWEEN @V_DTINI AND @V_DTFIM);
                      END
                      ELSE BEGIN
                        SELECT
                           @QTCMPAFSOLIPROD = SUM(ITS.QTSOLIPROD)/@V_PROD_VRFATOCONV
                        FROM
                           ITEMSOLI ITS, PRODUTO PS
                        WHERE (ITS.CDFILSOLI = @C_ETL_CDFILIAL)
                          AND (ITS.CDPRODUTO = PS.CDPRODUTO)
                          AND (PS.CDPRODESTO = @V_PROD_CDPRODESTO)
                          AND (ITS.DTPROGENTR BETWEEN @V_DTINI AND @V_DTFIM);
                      END;
                   END;
                   IF @QTCMPAFSOLIPROD IS NULL BEGIN
                     SET @QTCMPAFSOLIPROD = @V_ZERO;
                   END;

                   /*AF - Valor de Encargo*/
                   BEGIN
                      SELECT @VRCMPAFENCA = SUM(ENC.VRENCARGOAF)
                        FROM ENCARGOAF ENC
                      WHERE ENC.CDFILDEST = @C_ETL_CDFILIAL
                        AND ENC.DTENTRENCAF BETWEEN @V_DTINI AND @V_DTFIM
                        AND EXISTS (SELECT 1
                                      FROM AUTOFORNE, ITEMAUTF
                                     WHERE ITEMAUTF.CDFILDEST = ENC.CDFILDEST
                                       AND ITEMAUTF.CDFILLANC = ENC.CDFILLANC
                                       AND ITEMAUTF.NRAUTOFORN = ENC.NRAUTOFORN
                                       AND ITEMAUTF.DTPROGENTAF = ENC.DTENTRENCAF
                                       AND ITEMAUTF.DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM
                                       AND ITEMAUTF.CDFILDEST = @C_ETL_CDFILIAL
                                       AND AUTOFORNE.CDFILDEST = @C_ETL_CDFILIAL
                                       AND AUTOFORNE.CDFILDEST = ITEMAUTF.CDFILDEST
                                       AND AUTOFORNE.CDFILLANC = ITEMAUTF.CDFILLANC
                                       AND AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN
                                       AND AUTOFORNE.CDFORNECED = @C_FORN_CDFORNECED
                                       AND (ISNULL(AUTOFORNE.IDBAIXAAF,'0') <> '6')
                                       AND ITEMAUTF.CDPRODUTO = @C_PROD_CDPRODUTO
                                       AND ITEMAUTF.CDMARCA = @C_CDMARCA
                                       AND AUTOFORNE.CDOPERADOR = @C_CDCOMPRADOR)


                   END;
                   IF @VRCMPAFENCA IS NULL BEGIN
                     SET @VRCMPAFENCA = @V_ZERO;
                   END;

                   /*AF - Vr. Imposto*/
                   BEGIN
                     SELECT
                       @VRCMPIMPAF = SUM(IMP.VRIMPITMAF)
                     FROM
                       IMPITMAF IMP, AUTOFORNE AF
                     WHERE IMP.CDFILDEST = @C_ETL_CDFILIAL
                       AND IMP.CDPRODUTO = @C_PROD_CDPRODUTO
                       AND AF.CDOPERADOR = @C_CDCOMPRADOR
                       AND IMP.CDMARCA   = @C_CDMARCA
                       AND IMP.CDFILDEST = AF.CDFILDEST
                       AND IMP.CDFILLANC = AF.CDFILLANC
                       AND (ISNULL(AF.IDBAIXAAF,'0') <> '6')
                       AND AF.CDFORNECED = @C_FORN_CDFORNECED
                       AND IMP.NRAUTOFORN = AF.NRAUTOFORN
                       AND IMP.CDFISCITMAF = '1'
                       AND DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM;
                   END;
                   IF @VRCMPIMPAF IS NULL BEGIN
                      SET @VRCMPIMPAF = @V_ZERO;
                   END;

                   /*AF - Vr. Descontos*/

                   BEGIN
                     SELECT
                       @VRCMPAFDESC = SUM(VRPERDESAF)
                     FROM
                       ITEMAUTF I, AUTOFORNE A
                     WHERE A.NRAUTOFORN = I.NRAUTOFORN
                       AND I.CDFILDEST  = @C_ETL_CDFILIAL
                       AND A.CDOPERADOR = @C_CDCOMPRADOR
                       AND I.CDMARCA    = @C_CDMARCA
                       AND I.CDFILDEST  = A.CDFILDEST
                       AND I.CDFILLANC  = A.CDFILLANC
                       AND (ISNULL(A.IDBAIXAAF,'0') <> '6')
                       AND I.CDPRODUTO  = @C_PROD_CDPRODUTO
                       AND A.CDFORNECED = @C_FORN_CDFORNECED
                       AND DTPROGENTAF BETWEEN @V_DTINI AND @V_DTFIM;
                   END;
                   IF @VRCMPAFDESC IS NULL BEGIN 
                     SET @VRCMPAFDESC = @V_ZERO;
                   END;
                   
                     IF    (@V_VRCMPMEATUAF   <> @V_ZERO)
                        OR (@V_QTPRCMPATUAF   <> @V_ZERO)
                        OR (@V_QTPRCMPANTAF   <> @V_ZERO)
                        OR (@V_VRCMPMEANTAF   <> @V_ZERO)
                        OR (@VRCMPAFBAIXAPAR  <> @V_ZERO)
                        OR (@VRCMPAFBAIXATOT  <> @V_ZERO)
                        OR (@VRCMPAFBAIXAMAN  <> @V_ZERO)
                        OR (@VRCMPAFBAIXAENC  <> @V_ZERO)
                        OR (@VRCMPAFBAIXACAN  <> @V_ZERO)
                        OR (@VRCMPAFBAIXAABE  <> @V_ZERO)
                        OR (@QTCMPAFPREVISTA  <> @V_ZERO)
                        OR (@QTCMPAFSOLIPROD  <> @V_ZERO)
                        OR (@VRCMPAFENCA      <> @V_ZERO)
                        OR (@VRCMPIMPAF       <> @V_ZERO)
                        OR (@VRCMPAFDESC      <> @V_ZERO)
                     BEGIN

                       INSERT INTO ETLCOMPRASGERAF
                       (/*DIMENSES*/
                        CDFILIAL,           CDEMPRESA,          CDAREAGERE,         CDREGIAO,
                        CDSUPERVISOR,       CDGOPERAC,          CDPRODUTO,          NMPRODESTO,
                        CDANOBI,            CDMESBI,            BIETLCMP,           TRETLCMP,
                        SEETLCMP,           CDFORNECED,         CDCOMPRADOR,        CDMARCA,
                        /*FATOS*/
                        VRCMPMEATUAF,       VRCMPMEANTAF,       QTPRCMPATUAF,       QTPRCMPANTAF,
                        VRCMPAFBAIXATOT,    VRCMPAFBAIXAPAR,    VRCMPAFBAIXAMAN,    VRCMPAFBAIXAENC,
                        VRCMPAFBAIXACAN,    VRCMPAFBAIXAABE,    QTCMPAFPREVISTA,    QTCMPAFSOLIPROD,
                        VRCMPAFENCA,        VRCMPIMPAF,         VRCMPAFDESC
                       )
                       VALUES
                       (
                        /*DIMENSES*/
                        @C_ETL_CDFILIAL,     @C_ETL_CDEMPRESA,    @C_ETL_CDAREAGERE,   @C_ETL_CDREGIAO,
                        @C_ETL_CDSUPERVISOR, @C_ETL_CDGOPERAC,    @C_PROD_CDPRODUTO,   @C_PROD_CDPRODESTO+' '+@V_NMPRODESTO,
                        @V_ANO,              @V_MES,              @V_BIM,              @V_TRI,              
                        @V_SEM,              @C_FORN_CDFORNECED,  @C_CDCOMPRADOR,      @C_CDMARCA,
                        /*FATOS*/
                        @V_VRCMPMEATUAF,     @V_VRCMPMEANTAF,     @V_QTPRCMPATUAF,     @V_QTPRCMPANTAF,
                        @VRCMPAFBAIXATOT,    @VRCMPAFBAIXAPAR,    @VRCMPAFBAIXAMAN,    @VRCMPAFBAIXAENC,
                        @VRCMPAFBAIXACAN,    @VRCMPAFBAIXAABE,    @QTCMPAFPREVISTA,    @QTCMPAFSOLIPROD,
                        @VRCMPAFENCA,        @VRCMPIMPAF,         @VRCMPAFDESC
                        )

                        SET @V_COUNTER = @V_COUNTER + 1;
                        IF @V_COUNTER >= 500 BEGIN
                        COMMIT TRANSACTION;
                        SET @V_COUNTER = @V_ZERO;
                        BEGIN TRANSACTION;
                        END;

                     END; -- FIM DO IF DE INSERO

                    FETCH NEXT FROM C_MARCA INTO @C_CDMARCA;
                    END; -- FIM DO WHILE DE COMPRADOR
                    CLOSE C_MARCA;
                    DEALLOCATE C_MARCA;

                    FETCH NEXT FROM C_COMPR INTO @C_CDCOMPRADOR;

                    END; -- FIM DO WHILE DE COMPRADOR
                    CLOSE C_COMPR;
                    DEALLOCATE C_COMPR;


                       /*NF - MS ATUAL*/
                      /*QUANTIDADE DE PRODUTO COMPRADA*/
                     /*Valor total da compra*/
                     BEGIN
                        SELECT @V_QTPRCMPATUNF = SUM(QTITEMPROD),
                               @V_VRCMPMEATUNF = SUM(QTITEMPROD * VRUNITITEM)
                        FROM   NOTAFISCAL N,
                               ITEMPRODUTO I,
                               TIPOOPERAC T
                        WHERE  I.CDPRODUTO     = @C_PROD_CDPRODUTO
                          AND  N.CDFILIRECE    = @C_ETL_CDFILIAL
                          AND  N.CDFORNECED    = @C_FORN_CDFORNECED
                          AND  N.IDENTRSAIDOP  = 'E'
                          AND  T.IDGERANFCMP = 'S'
                          AND  N.CDTIPOOPER = T.CDTIPOOPER
                          AND  N.IDENTRSAIDOP = T.IDENTRSAIDOP
                          AND  N.DTENTRSAID BETWEEN @V_DTINI AND @V_DTFIM
                          AND  N.IDSTATUS    <> 'C'
                          AND  N.CDFILIAL   = I.CDFILIAL
                          AND  N.NRLANCTONF = I.NRLANCTONF;
                     END;
                     IF @V_QTPRCMPATUNF IS NULL BEGIN
                        SET @V_QTPRCMPATUNF = @V_ZERO;
                     END;
                     IF @V_VRCMPMEATUNF IS NULL BEGIN
                        SET @V_VRCMPMEATUNF = @V_ZERO;
                     END;

                       /*NF - MS ANTERIOR*/
                      /*QUANTIDADE DE PRODUTO COMPRADA*/
                     /*Valor total da compra*/
                     BEGIN
                        SELECT @V_QTPRCMPANTNF = SUM(QTITEMPROD),
                               @V_VRCMPMEANTNF = SUM(QTITEMPROD * VRUNITITEM)
                        FROM   NOTAFISCAL N,
                               ITEMPRODUTO I,
                               TIPOOPERAC T
                        WHERE  I.CDPRODUTO     = @C_PROD_CDPRODUTO
                          AND  N.CDFILIRECE    = @C_ETL_CDFILIAL
                          AND  N.CDFORNECED    = @C_FORN_CDFORNECED
                          AND  N.IDENTRSAIDOP  = 'E'
                          AND  T.IDGERANFCMP = 'S'
                          AND  N.CDTIPOOPER = T.CDTIPOOPER
                          AND  N.IDENTRSAIDOP = T.IDENTRSAIDOP
                          AND  N.DTENTRSAID BETWEEN @V_INIMESANT AND @V_FIMMESANT
                          AND  N.IDSTATUS    <> 'C'
                          AND  N.CDFILIAL   = I.CDFILIAL
                          AND  N.NRLANCTONF = I.NRLANCTONF;
                     END;
                     IF @V_QTPRCMPANTNF IS NULL BEGIN
                        SET @V_QTPRCMPANTNF = @V_ZERO;
                     END;
                     IF @V_VRCMPMEANTNF IS NULL BEGIN
                        SET @V_VRCMPMEANTNF = @V_ZERO;
                     END;

                     /*NF - Vr. Descontos*/

                   BEGIN
                     SELECT
                       @VRCMPNFDESC = SUM(IP.VRDESCITEM)
                     FROM
                       ITEMPRODUTO IP, NOTAFISCAL NF, TIPOOPERAC T
                     WHERE  IP.CDPRODUTO     = @C_PROD_CDPRODUTO
                       AND  NF.CDFILIRECE    = @C_ETL_CDFILIAL
                       AND  NF.CDFORNECED    = @C_FORN_CDFORNECED
                       AND  NF.CDOPERAPRO    = @C_CDCOMPRADOR
                       AND  NF.IDENTRSAIDOP  = 'E'
                       AND  T.IDGERANFCMP = 'S'
                       AND  NF.CDTIPOOPER = T.CDTIPOOPER
                       AND  NF.IDENTRSAIDOP = T.IDENTRSAIDOP
                       AND  NF.DTENTRSAID BETWEEN @V_DTINI AND @V_DTFIM
                       AND  NF.IDSTATUS    <> 'C'
                       AND  NF.CDFILIAL   = IP.CDFILIAL
                       AND  NF.NRLANCTONF = IP.NRLANCTONF;
                   END;
                   IF @VRCMPNFDESC IS NULL BEGIN
                      SET @VRCMPNFDESC = @V_ZERO;
                   END;

                   /*NF - Vr. Encargos*/

                   BEGIN
                     SELECT
                       @VRCMPNFENCA = SUM(IE.VRITEMENCA)
                     FROM
                       ITEMENCARGO IE,
                       ENCARGO EN,
                       NOTAFISCAL NF,
                       ITEMPRODUTO IP,
                       TIPOOPERAC T
                     WHERE IP.CDPRODUTO = @C_PROD_CDPRODUTO
                       AND IE.CDFILIAL   = @C_ETL_CDFILIAL
                       AND NF.CDFORNECED = @C_FORN_CDFORNECED
                       AND  NF.CDOPERAPRO = @C_CDCOMPRADOR
                       AND IE.NRLANCTONF = NF.NRLANCTONF
                       AND EN.CDENCARGO  = IE.CDENCARGO
                       AND (NF.DTENTRSAID BETWEEN @V_DTINI AND @V_DTFIM)
                       AND NF.IDENTRSAIDOP = 'E'
                       AND T.IDGERANFCMP = 'S'
                       AND NF.CDTIPOOPER = T.CDTIPOOPER
                       AND NF.IDENTRSAIDOP = T.IDENTRSAIDOP
                       AND NF.IDSTATUS <> 'C'
                       AND IE.CDFILIAL = NF.CDFILIAL
                       AND NF.CDFILIAL = IP.CDFILIAL
                       AND NF.NRLANCTONF = IP.NRLANCTONF;
                   END;
                   IF @VRCMPNFENCA IS NULL BEGIN
                      SET @VRCMPNFENCA = @V_ZERO;
                   END;

                   /*NF - Vr. Impostos*/

                   BEGIN
                     SELECT
                       @VRCMPIMPNF = SUM(II.VRIMPOSTOIT)
                     FROM
                       ITEMPROIMPOS II,
                       IMPOSTO IM,
                       ITEMPRODUTO IP,
                       NOTAFISCAL NF,
                       TIPOOPERAC T
                     WHERE IP.CDPRODUTO = @C_PROD_CDPRODUTO
                       AND NF.CDFILIRECE = @C_ETL_CDFILIAL
                       AND NF.CDOPERAPRO = @C_CDCOMPRADOR
                       AND NF.CDFORNECED = @C_FORN_CDFORNECED
                       AND II.NRLANCTONF = IP.NRLANCTONF
                       AND IM.CDIMPOSTO = II.CDIMPOSTO
                       AND II.CDFISCALIT = '1'
                       AND IP.CDFILIAL = II.CDFILIAL
                       AND IP.NRLANCTONF = II.NRLANCTONF
                       AND IP.NRSEQITPROD = II.NRSEQITPROD
                       AND NF.IDENTRSAIDOP  = 'E'
                       AND T.IDGERANFCMP = 'S'
                       AND NF.CDTIPOOPER = T.CDTIPOOPER
                       AND NF.IDENTRSAIDOP = T.IDENTRSAIDOP
                       AND NF.DTENTRSAID BETWEEN @V_DTINI AND @V_DTFIM
                       AND NF.IDSTATUS <> 'C'
                       AND NF.CDFILIAL   = IP.CDFILIAL
                       AND NF.NRLANCTONF = IP.NRLANCTONF;
                   END;
                   IF @VRCMPIMPNF IS NULL BEGIN
                      SET @VRCMPIMPNF = @V_ZERO;
                   END;

                     IF   (@V_VRCMPMEATUNF <> @V_ZERO)
                       OR (@V_VRCMPMEANTNF <> @V_ZERO)
                       OR (@V_QTPRCMPATUNF <> @V_ZERO)
                       OR (@V_QTPRCMPANTNF <> @V_ZERO)
                       OR (@VRCMPNFDESC    <> @V_ZERO)
                      BEGIN
                        INSERT INTO ETLCOMPRASGERNF
                           (/*DIMENSES*/
                            CDFILIAL,            CDEMPRESA,        CDAREAGERE,        CDREGIAO,
                            CDSUPERVISOR,        CDGOPERAC,        CDPRODUTO,         NMPRODESTO,
                            CDANOBI,             CDMESBI,          BIETLCMP,          TRETLCMP,
                            SEETLCMP,            CDFORNECED,
                            /*FATOS*/
                            VRCMPMEATUNF,      VRCMPMEANTNF,       QTPRCMPATUNF,      QTPRCMPANTNF,
                            VRCMPNFDESC,       VRCMPNFENCA,        VRCMPIMPNF
                            )
                        VALUES
                           (/*DIMENSES*/
                            @C_ETL_CDFILIAL,     @C_ETL_CDEMPRESA, @C_ETL_CDAREAGERE, @C_ETL_CDREGIAO,
                            @C_ETL_CDSUPERVISOR, @C_ETL_CDGOPERAC, @C_PROD_CDPRODUTO, @C_PROD_CDPRODESTO+' '+@V_NMPRODESTO,
                            @V_ANO,              @V_MES,           @V_BIM,            @V_TRI,
                            @V_SEM,              @C_FORN_CDFORNECED,
                            /*FATOS*/
                            @V_VRCMPMEATUNF,   @V_VRCMPMEANTNF,    @V_QTPRCMPATUNF,   @V_QTPRCMPANTNF,
                            @VRCMPNFDESC,      @VRCMPNFENCA,       @VRCMPIMPNF
                            );

                        SET @V_COUNTER = @V_COUNTER + 1;
                        IF @V_COUNTER >= 500 BEGIN
                        COMMIT TRANSACTION;
                        SET @V_COUNTER = @V_ZERO;
                        BEGIN TRANSACTION;
                        END;
                     END; --FINAL DO IF

                     FETCH NEXT FROM C_PROD INTO
                                                @C_PROD_CDPRODUTO;

                  END; --FINAL DO WHILE PARA C_PROD
                  CLOSE C_PROD;
                  DEALLOCATE C_PROD;

                  FETCH NEXT FROM C_FORN INTO
                                             @C_FORN_CDFORNECED;

               END; --FINAL DO WHILE PARA C_FORN
               CLOSE C_FORN;
               DEALLOCATE C_FORN;

            --END; --FINAL DA CONDIO POR DATA DE BI

            FETCH NEXT FROM C_ETL INTO
                           @C_ETL_CDFILIAL,    @C_ETL_CDAREAGERE, @C_ETL_DTINICIALBI,
                           @C_ETL_CDEMPRESA,   @C_ETL_CDREGIAO,   @C_ETL_CDGOPERAC,
                           @C_ETL_CDSUPERVISOR;

         END; --FINAL DO WHILE PARA C_ETL
         CLOSE C_ETL;
         DEALLOCATE C_ETL;

      COMMIT TRANSACTION;
      SET @V_DTINI = DATEADD(MM, 1, @V_DTINI);
   END;
END;

GO

/*REGISTRANDO FATOS E DIMENSES*/
BEGIN

----------------------------------FATOS E DIMENSES DE AF----------------------------------------------

   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPMEATUAF',   'Vr. compras (AF - ms atual)',  'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPMEANTAF',   'Vr. compras (AF - ms ant.)',   'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'QTPRCMPATUAF',   'Qtd. comprada (AF - ms atu.)', 'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'QTPRCMPANTAF',   'Qtd. comprada (AF - ms ant.)', 'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPAFBAIXATOT',   'Vr. AF Baixa Total',   'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPAFBAIXAPAR',   'Vr. AF Baixa Parcial', 'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPAFBAIXAMAN',   'Vr. AF Baixa Manual',  'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPAFBAIXAENC',   'Vr. AF Encerrada',     'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPAFBAIXACAN',   'Vr. AF Cancelada',     'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPAFBAIXAABE',   'Vr. AF em Aberto',     'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'QTCMPAFPREVISTA',   'Qtde Prevista',        'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'QTCMPAFSOLIPROD',   'Qtde Solicitada',      'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPAFENCA',       'Vr. Encargo AF',       'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPIMPAF',        'Vr. Imposto AF',       'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERAF', 'VRCMPAFDESC',       'Vr. Desconto AF',      'Compras';

   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDFILIAL',     'Filial',              'FILIAL',     'CDFILIAL',     'NMFILIAL',     NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDEMPRESA',    'Empresa',             'EMPRESA',    'CDEMPRESA',    'NMEMPRESA',    NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDAREAGERE',   'Regional',            'AREAGERE',   'CDAREAGERE',   'NMAREAGERE',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDREGIAO',     'Regio',              'REGIAO',     'CDREGIAO',     'NMREGIAO',     NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDSUPERVISOR', 'Supervisor',          'OPERADOR',   'CDOPERADOR',   'NMOPERADOR',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDGOPERAC',    'Gerente Operacional', 'OPERADOR',   'CDOPERADOR',   'NMOPERADOR',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDPRODUTO',    'Produto',             'PRODUTO',    'CDPRODUTO',    'NMPRODUTO',    NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDFORNECED',   'Fornecedor',          'FORNECEDOR', 'CDFORNECED',   'NMFANTFORN',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDANOBI',      'Ano',                 'ETLANOBI',   'CDANOBI',      'NMANOBI',      NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDMESBI',      'Ms',                 'ETLMESBI',   'CDMESBI',      'NMMESBI',      NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'BIETLCMP',     'Bimestre',             NULL,         NULL,           NULL,          NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'TRETLCMP',     'Trimestre',            NULL,         NULL,           NULL,          NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'SEETLCMP',     'Semestre',             NULL,         NULL,           NULL,          NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDOPERADOR',   'Comprador',           'OPERADOR',   'CDOPERADOR',   'NMOPERADOR',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERAF',  'CDMARCA',      'Marca',               'MARCA',      'CDMARCA',      'NMMARCA',      NULL;

----------------------------------FATOS E DIMENSES DE NF----------------------------------------------

   EXEC CRIA_FATOS 'ETLCOMPRASGERNF', 'VRCMPMEATUNF',   'Vr. compras (NF - ms atual)',  'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERNF', 'VRCMPMEANTNF',   'Vr. compras (NF - ms ant.)',   'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERNF', 'QTPRCMPATUNF',   'Qtd. comprada (NF - ms atu.)', 'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERNF', 'QTPRCMPANTNF',   'Qtd. comprada (NF - ms ant.)', 'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERNF', 'VRCMPNFDESC',       'Vr. Desconto NF',      'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERNF', 'VRCMPNFENCA',       'Vr. Encargo NF',       'Compras';
   EXEC CRIA_FATOS 'ETLCOMPRASGERNF', 'VRCMPIMPNF',        'Vr. Imposto NF',       'Compras';

   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDFILIAL',     'Filial',              'FILIAL',     'CDFILIAL',     'NMFILIAL',     NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDEMPRESA',    'Empresa',             'EMPRESA',    'CDEMPRESA',    'NMEMPRESA',    NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDAREAGERE',   'Regional',            'AREAGERE',   'CDAREAGERE',   'NMAREAGERE',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDREGIAO',     'Regio',              'REGIAO',     'CDREGIAO',     'NMREGIAO',     NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDSUPERVISOR', 'Supervisor',          'OPERADOR',   'CDOPERADOR',   'NMOPERADOR',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDGOPERAC',    'Gerente Operacional', 'OPERADOR',   'CDOPERADOR',   'NMOPERADOR',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDPRODUTO',    'Produto',             'PRODUTO',    'CDPRODUTO',    'NMPRODUTO',    NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDFORNECED',   'Fornecedor',          'FORNECEDOR', 'CDFORNECED',   'NMFANTFORN',   NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDANOBI',      'Ano',                 'ETLANOBI',   'CDANOBI',      'NMANOBI',      NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'CDMESBI',      'Ms',                 'ETLMESBI',   'CDMESBI',      'NMMESBI',      NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'BIETLCMP',     'Bimestre',             NULL,         NULL,           NULL,          NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'TRETLCMP',     'Trimestre',            NULL,         NULL,           NULL,          NULL;
   EXEC CRIA_DIME 'ETLCOMPRASGERNF',  'SEETLCMP',     'Semestre',             NULL,         NULL,           NULL,          NULL;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'ETL_COMPRASGER','5.20.000';
GO

